@@ -1,4 +1,4 @@
-# -*- Mode:Python; indent-tabs-mode:nil; tab-width:4 -*-
+# -*- Mode:Python; indent-tabs-mode:nil; tab-width:4; encoding:utf8 -*-
 #
 # Copyright 2002 Ben Escoto <ben@emerose.org>
 # Copyright 2007 Kenneth Loafman <kenneth@loafman.com>
@@ -21,16 +21,12 @@
 
 u"""Classes and functions on collections of backup volumes"""
 
-from past.builtins import cmp
-from builtins import filter
 from builtins import str
 from builtins import zip
 from builtins import map
 from builtins import range
 from builtins import object
 
-import types
-import gettext
 import sys
 
 from duplicity import log
@@ -38,7 +34,7 @@ from duplicity import file_naming
 from duplicity import path
 from duplicity import util
 from duplicity import dup_time
-from duplicity import globals
+from duplicity import config
 from duplicity import manifest
 from duplicity import util
 from duplicity.gpg import GPGError
@@ -149,12 +145,15 @@ class BackupSet(object):
         u"""
         Add local and remote manifest filenames to backup set
         """
-        assert not self.remote_manifest_name, (self.remote_manifest_name,
-                                               remote_filename)
+        assert not self.remote_manifest_name, \
+            u"Cannot set filename of remote manifest to %s; already set to %s." % (
+                remote_filename,
+                self.remote_manifest_name,
+            )
         self.remote_manifest_name = remote_filename
 
-        if self.action not in [u"collection-status", u"replicate"]:
-            local_filename_list = globals.archive_dir_path.listdir()
+        if self.action != u"replicate":
+            local_filename_list = config.archive_dir_path.listdir()
         else:
             local_filename_list = []
         for local_filename in local_filename_list:
@@ -164,7 +163,7 @@ class BackupSet(object):
                     pr.start_time == self.start_time and
                     pr.end_time == self.end_time):
                 self.local_manifest_path = \
-                    globals.archive_dir_path.append(local_filename)
+                    config.archive_dir_path.append(local_filename)
 
                 self.set_files_changed()
                 break
@@ -180,8 +179,8 @@ class BackupSet(object):
         except Exception:
             log.Debug(_(u"BackupSet.delete: missing %s") % [util.fsdecode(f) for f in rfn])
             pass
-        if self.action not in [u"collection-status", u"replicate"]:
-            local_filename_list = globals.archive_dir_path.listdir()
+        if self.action != u"replicate":
+            local_filename_list = config.archive_dir_path.listdir()
         else:
             local_filename_list = []
         for lfn in local_filename_list:
@@ -190,7 +189,7 @@ class BackupSet(object):
                     pr.start_time == self.start_time and
                     pr.end_time == self.end_time):
                 try:
-                    globals.archive_dir_path.append(lfn).delete()
+                    config.archive_dir_path.append(lfn).delete()
                 except Exception:
                     log.Debug(_(u"BackupSet.delete: missing %s") % [util.fsdecode(f) for f in lfn])
                     pass
@@ -416,16 +415,16 @@ class BackupChain(object):
         l = []
         for s in self.get_all_sets():
             if s.time:
-                type = u"full"
+                btype = u"full"
                 time = s.time
             else:
-                type = u"inc"
+                btype = u"inc"
                 time = s.end_time
             if s.encrypted:
                 enc = u"enc"
             else:
                 enc = u"noenc"
-            l.append(u"%s%s %s %d %s" % (prefix, type, dup_time.timetostring(time), (len(s)), enc))
+            l.append(u"%s%s %s %d %s" % (prefix, btype, dup_time.timetostring(time), (len(s)), enc))
         return l
 
     def __str__(self):
@@ -444,12 +443,12 @@ class BackupChain(object):
 
         for s in self.get_all_sets():
             if s.time:
-                type = _(u"Full")
+                btype = _(u"Full")
                 time = s.time
             else:
-                type = _(u"Incremental")
+                btype = _(u"Incremental")
                 time = s.end_time
-            l.append(set_schema % (type, dup_time.timetopretty(time), len(s)))
+            l.append(set_schema % (btype, dup_time.timetopretty(time), len(s)))
 
         l.append(u"-------------------------")
         return u"\n".join(l)
@@ -485,14 +484,14 @@ class SignatureChain(object):
         Return new SignatureChain.
 
         local should be true iff the signature chain resides in
-        globals.archive_dir_path and false if the chain is in
-        globals.backend.
+        config.archive_dir_path and false if the chain is in
+        config.backend.
 
-        @param local: True if sig chain in globals.archive_dir_path
+        @param local: True if sig chain in config.archive_dir_path
         @type local: Boolean
 
         @param location: Where the sig chain is located
-        @type location: globals.archive_dir_path or globals.backend
+        @type location: config.archive_dir_path or config.backend
         """
         if local:
             self.archive_dir_path, self.backend = location, None
@@ -723,7 +722,7 @@ class CollectionsStatus(object):
                   len(backend_filename_list))
 
         # get local filename list
-        if self.action not in [u"collection-status", u"replicate"]:
+        if self.action != u"replicate":
             local_filename_list = self.archive_dir_path.listdir()
         else:
             local_filename_list = []
@@ -856,7 +855,7 @@ class CollectionsStatus(object):
             Try adding filename to existing sets, or make new one
             """
             pr = file_naming.parse(filename)
-            for set in sets:
+            for set in sets:  # pylint: disable=redefined-builtin
                 if set.add_filename(filename, pr):
                     log.Debug(_(u"File %s is part of known set") % (util.fsdecode(filename),))
                     break
@@ -874,7 +873,7 @@ class CollectionsStatus(object):
 
         chains, orphaned_sets = [], []
 
-        def add_to_chains(set):
+        def add_to_chains(set):  # pylint: disable=redefined-builtin
             u"""
             Try adding set to existing chains, or make new one
             """
@@ -902,14 +901,14 @@ class CollectionsStatus(object):
         Sort set list by end time, return (sorted list, incomplete)
         """
         time_set_pairs, incomplete_sets = [], []
-        for set in set_list:
+        for set in set_list:  # pylint: disable=redefined-builtin
             if not set.is_complete():
                 incomplete_sets.append(set)
             elif set.type == u"full":
                 time_set_pairs.append((set.time, set))
             else:
                 time_set_pairs.append((set.end_time, set))
-        time_set_pairs.sort()
+        time_set_pairs.sort(key=lambda x: x[0])
         return ([p[1] for p in time_set_pairs], incomplete_sets)
 
     def get_signature_chains(self, local, filelist=None):
@@ -924,7 +923,7 @@ class CollectionsStatus(object):
             if filelist is not None:
                 return filelist
             elif local:
-                if self.action not in [u"collection-status", u"replicate"]:
+                if self.action != u"replicate":
                     return self.archive_dir_path.listdir()
                 else:
                     return []
@@ -1048,7 +1047,7 @@ class CollectionsStatus(object):
                          dup_time.timetostring(oldest.start_time))
             return oldest
 
-    def get_extraneous(self, extra_clean):
+    def get_extraneous(self):
         u"""
         Return list of the names of extraneous duplicity files
 
@@ -1060,15 +1059,6 @@ class CollectionsStatus(object):
         local_filenames = []
         remote_filenames = []
         ext_containers = self.orphaned_backup_sets + self.incomplete_backup_sets
-        if extra_clean:
-            old_sig_chains = self.all_sig_chains[:]
-            if self.matched_chain_pair:
-                matched_sig_chain = self.matched_chain_pair[0]
-                for sig_chain in self.all_sig_chains:
-                    if (sig_chain.start_time == matched_sig_chain.start_time and
-                            sig_chain.end_time == matched_sig_chain.end_time):
-                        old_sig_chains.remove(sig_chain)
-            ext_containers += old_sig_chains
         for set_or_chain in ext_containers:
             if set_or_chain.backend:
                 remote_filenames.extend(set_or_chain.get_filenames())
@@ -1164,7 +1154,7 @@ class CollectionsStatus(object):
         if len(self.all_backup_chains) < n:
             return None
 
-        sorted = self.all_backup_chains[:]
+        sorted = self.all_backup_chains[:]  # pylint: disable=redefined-builtin
         sorted.sort(key=lambda x: x.get_first().time)
 
         sorted.reverse()
@@ -1217,6 +1207,7 @@ class CollectionsStatus(object):
         specified_file_backup_set = []
         specified_file_backup_type = []
 
+        modified_filepath = util.fsencode(modified_filepath)
         for bs in all_backup_set:
             filelist = [fileinfo[1] for fileinfo in bs.get_files_changed()]
             if modified_filepath in filelist:
@@ -1243,7 +1234,7 @@ class FileChangedStatus(object):
             backup_type = s[0]
             backup_set = s[1]
             if backup_set.time:
-                type = _(u"Full")
+                type = _(u"Full")  # pylint: disable=redefined-builtin
             else:
                 type = _(u"Incremental")
             l.append(set_schema % (type, dup_time.timetopretty(backup_set.get_time()), backup_type.title()))
